@@ -1,18 +1,16 @@
-// =================================================================
-//          #     #                 #     #
-//          ##    #   ####   #####  ##    #  ######   #####
-//          # #   #  #    #  #    # # #   #  #          #
-//          #  #  #  #    #  #    # #  #  #  #####      #
-//          #   # #  #    #  #####  #   # #  #          #
-//          #    ##  #    #  #   #  #    ##  #          #
-//          #     #   ####   #    # #     #  ######     #
+// ==========================================================================
+//     _   _ _ ____            ____          _____
+//    | | | (_)  _ \ ___ _ __ / ___|___  _ _|_   _| __ __ _  ___ ___ _ __
+//    | |_| | | |_) / _ \ '__| |   / _ \| '_ \| || '__/ _` |/ __/ _ \ '__|
+//    |  _  | |  __/  __/ |  | |__| (_) | | | | || | | (_| | (_|  __/ |
+//    |_| |_|_|_|   \___|_|   \____\___/|_| |_|_||_|  \__,_|\___\___|_|
 //
-//       ---   The NorNet Testbed for Multi-Homed Systems  ---
-//                       https://www.nntb.no
-// =================================================================
+//       ---  High-Performance Connectivity Tracer (HiPerConTracer)  ---
+//                 https://www.nntb.no/~dreibh/hipercontracer/
+// ==========================================================================
 //
 // High-Performance Connectivity Tracer (HiPerConTracer)
-// Copyright (C) 2015-2022 by Thomas Dreibholz
+// Copyright (C) 2015-2025 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,65 +31,83 @@
 #define RESULTSWRITER_H
 
 #include <chrono>
+#include <filesystem>
 #include <fstream>
 #include <set>
 #include <string>
 
 #include <boost/asio/ip/address.hpp>
-#include <boost/filesystem.hpp>
 #include <boost/iostreams/filtering_stream.hpp>
 
 
 enum ResultsWriterCompressor {
    None  = 0,
    GZip  = 1,
-   BZip2 = 2
-   // XZ = 3
+   BZip2 = 2,
+   XZ    = 3
 };
 
 
 class ResultsWriter
 {
    public:
-   ResultsWriter(const std::string&            directory,
+   ResultsWriter(const std::string&            programID,
+                 const unsigned int            measurementID,
+                 const std::string&            directory,
                  const std::string&            uniqueID,
-                 const std::string&            formatName,
+                 const std::string&            prefix,
                  const unsigned int            transactionLength,
+                 const unsigned int            timestampDepth,
                  const uid_t                   uid,
                  const gid_t                   gid,
                  const ResultsWriterCompressor compressor);
    virtual ~ResultsWriter();
 
+   void specifyOutputFormat(const std::string& outputFormatName,
+                            const unsigned int outputFormatVersion);
+
+   inline unsigned int measurementID() const {
+      return MeasurementID;
+   }
+
    bool prepare();
    bool changeFile(const bool createNewFile = true);
    bool mayStartNewTransaction();
    void insert(const std::string& tuple);
 
    static ResultsWriter* makeResultsWriter(std::set<ResultsWriter*>&       resultsWriterSet,
+                                           const std::string&              programID,
+                                           const unsigned int              measurementID,
                                            const boost::asio::ip::address& sourceAddress,
-                                           const std::string&              resultsFormat,
+                                           const std::string&              resultsPrefix,
                                            const std::string&              resultsDirectory,
                                            const unsigned int              resultsTransactionLength,
+                                           const unsigned int              resultsTimestampDepth,
                                            const uid_t                     uid,
                                            const gid_t                     gid,
-                                           const ResultsWriterCompressor   compressor = BZip2);
+                                           const ResultsWriterCompressor   compressor = ResultsWriterCompressor::XZ);
 
    protected:
-   const boost::filesystem::path         Directory;
-   const std::string                     UniqueID;
-   const std::string                     FormatName;
+   const std::string                     ProgramID;
+   const unsigned int                    MeasurementID;
+   const std::filesystem::path           Directory;
+   const std::string                     Prefix;
    const unsigned int                    TransactionLength;
+   const unsigned int                    TimestampDepth;
    const uid_t                           UID;
    const gid_t                           GID;
    const ResultsWriterCompressor         Compressor;
 
-   boost::filesystem::path               TempFileName;
-   boost::filesystem::path               TargetFileName;
+   std::string                           UniqueID;
+   std::filesystem::path                 TempFileName;
+   std::filesystem::path                 TargetFileName;
    size_t                                Inserts;
    unsigned long long                    SeqNumber;
    std::ofstream                         OutputFile;
    boost::iostreams::filtering_ostream   OutputStream;
    std::chrono::steady_clock::time_point OutputCreationTime;
+   std::string                           OutputFormatName;
+   unsigned int                          OutputFormatVersion;
 };
 
 #endif
